#!/usr/bin/perl
#
# Example Perl Script to demonstrate Redirection,
# without Web Agent restriction, to any desired URL, 
# after invoking Web Agent authentication on the WebSite
# of the Script.  
#
# The practical implementation of an actual-use Script,
# however, may limit access to only certain Web Sites and
# URLs chosen by the Web Administrator.  The implied intent, 
# of providing a Script for redirection, is to transfer 
# control of Redirected URL restriction from the Web Agent
# System to the Web Administrator.
#
# To control access to "allowable" Web Sites or URLs that a 
# user might attempt Redirection to, an actual-use Script would
# perform string comparisons between the expanded "Redirection"
# argument to this Script, "$targetURL", and a list of "allowable"
# or "dis-allowable" URLs or <hostname.domain> combinations
# imbedded in the URL.  This list would be maintained by the 
# Web Administrator.
#
# Example specification of script invocation, in a URL, is 
# as follows:
#
# Windows:
# -------
#   http://HostName/WebID/IISWebAgentIF.dll
#    ?referrer=/Scripts/PerlScriptRedirect.pl
#      ?target=http://RedirectHostName/file.txt
#
# Unix:
# -------
#   http://HostName/webauthentication
#    ?referrer=/Scripts/PerlScriptRedirect.pl
#      ?target=http://RedirectHostName/file.txt
#
# The HTML code, including the "href" statement, in this example, 
# presents a method of fallback Redirection in case of failure of 
# the "302 Header" to accomplish the same ends.  Ideally, one would 
# never see the "Redirect" page defined by this HTML, for the 
# "302 Redirect Header" should take the user directly to the desired
# URL.
#===================================================================

$targetURL='/';
$cgi_arg = $ENV{'QUERY_STRING'};

if ($cgi_arg =~ /target=(.*)/) { $targetURL = $1; }

# An "actual-use" Script would perform string comparisons,
# HERE, between the input URL, (including <hostname.domain>),
# and a list of "allowable" or "dis-allowable" URLs or
# <hostname.domain> combinations.  The input URL is represented
# in "$targetURL".

print <<__END__;
Location: $targetURL
Content-type: text/html

<HTML>

    <HEAD><TITLE>CGI Script Redirect</TITLE></HEAD>

    <BODY>
        <CENTER>
            <FONT COLOR="red">
                <H1>CGI Script Redirect</H1>
            </FONT>

            <P><H2>Click "Continue" to Redirect<strong></strong></H2></P>

            <P><H2><A href="$targetURL">Continue</A></H2></P>

            <HR>

        </CENTER>
    </BODY>

</HTML>

__END__
